@@ -1,7 +1,7 @@
 package Pod::Weaver::Plugin::WordList;
 
-our $DATE = '2016-01-13'; # DATE
-our $VERSION = '0.05'; # VERSION
+our $DATE = '2018-02-20'; # DATE
+our $VERSION = '0.060'; # VERSION
 
 use 5.010001;
 use Moose;
@@ -99,8 +99,6 @@ sub weave_section {
 1;
 # ABSTRACT: Plugin to use when building WordList::* distribution
 
-
-
 __END__
 
 =pod
@@ -113,7 +111,7 @@ Pod::Weaver::Plugin::WordList - Plugin to use when building WordList::* distribu
 
 =head1 VERSION
 
-This document describes version 0.05 of Pod::Weaver::Plugin::WordList (from Perl distribution Pod-Weaver-Plugin-WordList), released on 2016-01-13.
+This document describes version 0.060 of Pod::Weaver::Plugin::WordList (from Perl distribution Pod-Weaver-Plugin-WordList), released on 2018-02-20.
 
 =head1 SYNOPSIS
 
@@ -128,7 +126,7 @@ it does the following:
 
 =over
 
-=item * Add a Synopsis section (it doesn't already exist) showing how to use the module
+=item * Add a Synopsis section (if doesn't already exist) showing how to use the module
 
 =item * Add Statistics section showing statistics from C<%STATS> (which can be generated by DZP:WordList)
 
@@ -136,10 +134,6 @@ it does the following:
 
 =for Pod::Coverage ^(weave_section)$
 
-=head1 SEE ALSO
-
-L<Dist::Zilla::Plugin::WordList>
-
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Pod-Weaver-Plugin-WordList>.
@@ -156,16 +150,23 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
+=head1 SEE ALSO
+
+L<WordList>
+
+L<Dist::Zilla::Plugin::WordList>
+
+L<Pod::Weaver::Plugin::WordListC>
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by perlancar@cpan.org.
+This software is copyright (c) 2018, 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
